@@ -502,7 +502,10 @@ def test_composite_initial_state_complex() -> None:
     outer_path = ('universe', 'agent')
     pq = PoQo({})
     pq_composite = pq.generate(path=outer_path)
-    pq_initial = pq_composite.initial_state()
+    pq_initial = pq_composite.initial_state(
+        config={
+            'initial_state': {
+                'universe': {'agent': {'aaa': {'x': 4}}}}})
 
     expected_initial = {
         'universe': {
@@ -767,7 +770,7 @@ def test_aggregate_composer() -> None:
     }
     aggregate.add_composers(
         composers=[ToyComposer(config2)],
-        config={})
+        config={'two': {}})
     composite2 = aggregate.generate()
 
     # add composer (single)
@@ -778,7 +781,7 @@ def test_aggregate_composer() -> None:
     }
     aggregate.add_composer(
         composer=ToyComposer(config3),
-        config={})
+        config={'three': {}})
     composite3 = aggregate.generate()
 
     assert all(
