@@ -117,6 +117,19 @@ class Process(metaclass=abc.ABCMeta):
         self.parameters.setdefault('time_step', DEFAULT_TIME_STEP)
         self.schema: Optional[dict] = None
 
+    def __getstate__(self) -> dict:
+        """Return parameters
+
+        This is sufficient to reproduce the Process if there are no
+        hidden states. Processes with hidden states may need to write
+        their own __getstate__.
+        """
+        return self.parameters
+
+    def __setstate__(self, state: dict) -> None:
+        """Initialize process with parameters"""
+        self.__init__(parameters=state)  # type: ignore
+
     def initial_state(self, config: Optional[dict] = None) -> State:
         """Get initial state in embedded path dictionary.
 
